@@ -23,25 +23,29 @@ public:
 protected:
   java_qualifierst &operator=(const java_qualifierst &other);
 public:
-  virtual std::unique_ptr<qualifierst> clone() const override;
+  std::unique_ptr<c_qualifierst> clone() const override;
 
-  virtual qualifierst &operator+=(const qualifierst &other) override;
+  java_qualifierst &operator+=(const java_qualifierst &other);
 
   const std::vector<java_annotationt> &get_annotations() const
   {
     return annotations;
   }
-  virtual std::size_t count() const override;
+  std::size_t count() const override;
 
-  virtual void clear() override;
+  void clear() override;
 
-  virtual void read(const typet &src) override;
-  virtual void write(typet &src) const override;
+  void read(const typet &src) override;
+  void write(typet &src) const override;
 
-  virtual bool is_subset_of(const qualifierst &other) const override;
-  virtual bool operator==(const qualifierst &other) const override;
+  bool is_subset_of(const java_qualifierst &other) const;
+  bool operator==(const java_qualifierst &other) const;
+  bool operator!=(const java_qualifierst &other) const
+  {
+    return !(*this == other);
+  }
 
-  virtual std::string as_string() const override;
+  std::string as_string() const override;
 };
 
 #endif // CPROVER_JAVA_BYTECODE_JAVA_QUALIFIERS_H
