@@ -4,7 +4,7 @@ Module: Goto Checker using Single Path Symbolic Execution for Java
 
 Author: Daniel Kroening, Peter Schrammel
 
- \*******************************************************************/
+\*******************************************************************/
 
 /// \file
 /// Goto Checker using Single Path Symbolic Execution for Java
@@ -12,13 +12,9 @@ Author: Daniel Kroening, Peter Schrammel
 #ifndef CPROVER_JAVA_BYTECODE_JAVA_SINGLE_PATH_SYMEX_CHECKER_H
 #define CPROVER_JAVA_BYTECODE_JAVA_SINGLE_PATH_SYMEX_CHECKER_H
 
-#include <goto-checker/bmc_util.h>
-#include <goto-checker/counterexample_beautification.h>
 #include <goto-checker/single_path_symex_checker.h>
-#include <goto-symex/build_goto_trace.h>
 
 #include "java_bmc_util.h"
-#include "java_trace_validation.h"
 
 class java_single_path_symex_checkert : public single_path_symex_checkert
 {
