@@ -7,22 +7,25 @@ Author: Diffblue Ltd.
 
 \*******************************************************************/
 
+#include <util/c_types.h>
+#include <util/namespace.h>
+#include <util/std_code.h>
+#include <util/symbol_table.h>
+
 #include <java_bytecode/java_bytecode_language.h>
 #include <java_bytecode/java_string_library_preprocess.h>
 #include <langapi/language_util.h>
 #include <langapi/mode.h>
 #include <testing-utils/use_catch.h>
-#include <util/c_types.h>
-#include <util/fresh_symbol.h>
-#include <util/namespace.h>
-#include <util/std_code.h>
+
+#include <regex>
 
 refined_string_exprt convert_exprt_to_string_exprt_unit_test(
   java_string_library_preprocesst &preprocess,
   const exprt &deref,
   const source_locationt &loc,
   const irep_idt &function_id,
-  symbol_tablet &symbol_table,
+  symbol_table_baset &symbol_table,
   code_blockt &init_code)
 {
   return preprocess.convert_exprt_to_string_exprt(
@@ -39,6 +42,7 @@ TEST_CASE("Convert exprt to string exprt")
     namespacet ns(symbol_table);
     code_blockt code;
     java_string_library_preprocesst preprocess;
+    preprocess.initialize_known_type_table();
     preprocess.add_string_type("java.lang.String", symbol_table);
     struct_tag_typet java_string_type("java::java.lang.String");
     symbol_exprt expr("a", pointer_type(java_string_type));
