@@ -12,16 +12,20 @@ STATIC_ASSERT(sizeof(void *)==sizeof(size_t));
 
 #ifdef _WIN32
 
-#ifdef _WIN64
+#  ifdef _WIN64
 
 STATIC_ASSERT(sizeof(void *)==8);
 STATIC_ASSERT(sizeof(int)==4);
 STATIC_ASSERT(sizeof(long int)==4);
 STATIC_ASSERT(sizeof(long long int)==8);
 STATIC_ASSERT(sizeof(wchar_t)==2);
+#    ifdef __MINGW64__
+STATIC_ASSERT(sizeof(long double) == 16);
+#    else
 STATIC_ASSERT(sizeof(long double)==8);
+#    endif
 
-#else
+#  else
 
 STATIC_ASSERT(sizeof(void *)==4);
 STATIC_ASSERT(sizeof(int)==4);
@@ -30,7 +34,7 @@ STATIC_ASSERT(sizeof(long long int)==8);
 STATIC_ASSERT(sizeof(wchar_t)==2);
 STATIC_ASSERT(sizeof(long double)==8);
 
-#endif
+#  endif
 
 #else
 
