@@ -1,5 +1,9 @@
 #include <assert.h>
 
+#ifndef __GNUC__
+void __atomic_signal_fence(int);
+#endif
+
 int main()
 {
   __atomic_signal_fence(0);
