@@ -1,9 +1,10 @@
 #include <assert.h>
 #include <stdlib.h>
 
+#include <limits.h>
+
 int main()
 {
-  llabs();
-  assert(0);
+  assert(llabs(LLONG_MIN + 1) == LLONG_MAX);
   return 0;
 }
