@@ -1,7 +1,7 @@
 void boolean()
 {
   __CPROVER_bool a, b;
-  __CPROVER_assert((a ≡ b) == (a == b), "≥");
+  __CPROVER_assert((a ≡ b) == (a == b), "≡");
   __CPROVER_assert((a ≢ b) == (a != b), "≢");
   __CPROVER_assert((a ⇒ b) == (!a || b), "⇒");
   __CPROVER_assert((a ⇔ b) == (a == b), "⇔");
@@ -16,7 +16,7 @@ void relations()
   int a, b;
   __CPROVER_assert((a ≥ b) == (a >= b), "≥");
   __CPROVER_assert((a ≤ b) == (a <= b), "≤");
-  __CPROVER_assert((a ≡ b) == (a == b), "≥");
+  __CPROVER_assert((a ≡ b) == (a == b), "≡");
   __CPROVER_assert((a ≢ b) == (a != b), "≢");
   __CPROVER_assert((− a) == (-a), "−");
 }
@@ -25,6 +25,7 @@ void quantifiers()
 {
   __CPROVER_assert((∀ int i; 1) == 1, "∀");
   __CPROVER_assert((∃ int i; 1) == 1, "∃");
+  __CPROVER_assert((\lambda int i; i + 1)(1) == 2, "lambda");
 }
 
 int main()
