@@ -11,7 +11,7 @@ void main()
   __CPROVER_bool y[8] = {false};
   bool *z = calloc(8, sizeof(bool));
 
-  unsigned idx;
+  unsigned char idx;
   __CPROVER_assume(0 <= idx && idx < 8);
 
   assert(w[idx] == x[idx]);
