@@ -3,6 +3,7 @@ int main()
   int a;
   unsigned int b;
   float f;
+  char *p;
 
   a = 0;
   a = -100;
@@ -10,6 +11,7 @@ int main()
   b = a * 2;
   a = -2147483647;
   f = 0.1f;
+  p = (char *)123;
 
   __CPROVER_assert(0, "");
 }
