@@ -1,9 +1,5 @@
 #include <assert.h>
 
-#ifdef _MSC_VER
-#  define _Static_assert(x, m) static_assert(x, m)
-#endif
-
 int main()
 {
   _Bool b1, b2;
