@@ -3,10 +3,10 @@ int main()
 {
   int i=0, j=2;
 
-  if (i==0) 
+  if(i == 0)
   {
     i++;
     j++;
   }
-  assert(j!=3);
+  __CPROVER_assert(j != 3, "j!=3");
 }
