@@ -3,11 +3,11 @@ int main()
 {
   int i=0, j=2;
 
-  while (i<50) 
+  while(i < 50)
   {
     i++;
     j++;
   }
-  assert(i<51);
+  __CPROVER_assert(i < 51, "i<51");
 }
 
