@@ -6,7 +6,7 @@ int main()
   if (i==0)
     y=1;
 
-  assert(y==1);
+  __CPROVER_assert(y == 1, "y==1");
 
   return 0;
 }
