@@ -5,7 +5,7 @@ int main()
 
   if(i>0)
     if(i<3)
-      assert(i>=1 || i<=2);
+      __CPROVER_assert(i >= 1 || i <= 2, "i>=1 || i<=2");
 
   return 0;
 }
