@@ -9,16 +9,16 @@ int main(int argc, char *argv[])
   int **x=&p;
 
   // Reading from a pointer to a pointer that's been dereferenced twice
-  assert(**x==0);
-  assert(**x==1);
+  __CPROVER_assert(**x == 0, "**x==0");
+  __CPROVER_assert(**x == 1, "**x==1");
   a=1;
-  assert(**x==1);
-  assert(**x==0);
+  __CPROVER_assert(**x == 1, "**x==1");
+  __CPROVER_assert(**x == 0, "**x==0");
 
   // Writing to a pointer to a pointer that's been dereferenced twice
   **x=2;
-  assert(a==2);
-  assert(a==1);
+  __CPROVER_assert(a == 2, "a==2");
+  __CPROVER_assert(a == 1, "a==1");
 
   return 0;
 }
