@@ -4,7 +4,14 @@ typedef int (*fptr_t)(long long);
 
 void use_f(fptr_t fptr)
 {
+#if !defined(__BYTE_ORDER__) || __BYTE_ORDER__ == __ORDER_LITTLE_ENDIAN__
   assert(fptr(10) == 11);
+#else
+  if(sizeof(int) == sizeof(long long))
+    assert(fptr(10) == 11);
+  else
+    assert(fptr(10) == 1);
+#endif
 }
 
 int f(int x)
