@@ -9,7 +9,7 @@ int main()
     int j;
     i = 2;
     s = __CPROVER_string_literal("pippo");
-    if (__CPROVER_char_at(s, i) == __CPROVER_char_literal("p")) {
+    if (__CPROVER_char_at(s, i) == 'p') {
         j = 1;
     }
     assert(j == 1);
