@@ -11,30 +11,27 @@ Author: Daniel Kroening, kroening@kroening.com
 
 #include "ai.h"
 
-#include <cassert>
 #include <memory>
 #include <sstream>
 #include <type_traits>
 
 #include <util/invariant.h>
-#include <util/std_code.h>
-#include <util/std_expr.h>
 
 void ai_baset::output(
   const namespacet &ns,
   const goto_functionst &goto_functions,
   std::ostream &out) const
 {
-  forall_goto_functions(f_it, goto_functions)
+  for(const auto &gf_entry : goto_functions.function_map)
   {
-    if(f_it->second.body_available())
+    if(gf_entry.second.body_available())
     {
       out << "////\n";
-      out << "//// Function: " << f_it->first << "\n";
+      out << "//// Function: " << gf_entry.first << "\n";
       out << "////\n";
       out << "\n";
 
-      output(ns, f_it->first, f_it->second.body, out);
+      output(ns, gf_entry.first, gf_entry.second.body, out);
     }
   }
 }
@@ -45,15 +42,17 @@ void ai_baset::output(
   const goto_programt &goto_program,
   std::ostream &out) const
 {
+  (void)function_id; // unused parameter
+
   forall_goto_program_instructions(i_it, goto_program)
   {
-    out << "**** " << i_it->location_number << " "
-        << i_it->source_location << "\n";
+    out << "**** " << i_it->location_number << " " << i_it->source_location()
+        << "\n";
 
     abstract_state_before(i_it)->output(out, *this, ns);
     out << "\n";
     #if 1
-    goto_program.output_instruction(ns, function_id, out, *i_it);
+    i_it->output(out);
     out << "\n";
     #endif
   }
@@ -65,16 +64,16 @@ jsont ai_baset::output_json(
 {
   json_objectt result;
 
-  forall_goto_functions(f_it, goto_functions)
+  for(const auto &gf_entry : goto_functions.function_map)
   {
-    if(f_it->second.body_available())
+    if(gf_entry.second.body_available())
     {
-      result[id2string(f_it->first)] =
-        output_json(ns, f_it->first, f_it->second.body);
+      result[id2string(gf_entry.first)] =
+        output_json(ns, gf_entry.first, gf_entry.second.body);
     }
     else
     {
-      result[id2string(f_it->first)]=json_arrayt();
+      result[id2string(gf_entry.first)] = json_arrayt();
     }
   }
 
@@ -86,17 +85,19 @@ jsont ai_baset::output_json(
   const irep_idt &function_id,
   const goto_programt &goto_program) const
 {
+  (void)function_id; // unused parameter
+
   json_arrayt contents;
 
   forall_goto_program_instructions(i_it, goto_program)
   {
     // Ideally we need output_instruction_json
     std::ostringstream out;
-    goto_program.output_instruction(ns, function_id, out, *i_it);
+    i_it->output(out);
 
     json_objectt location{
       {"locationNumber", json_numbert(std::to_string(i_it->location_number))},
-      {"sourceLocation", json_stringt(i_it->source_location.as_string())},
+      {"sourceLocation", json_stringt(i_it->source_location().as_string())},
       {"abstractState", abstract_state_before(i_it)->output_json(*this, ns)},
       {"instruction", json_stringt(out.str())}};
 
@@ -112,17 +113,18 @@ xmlt ai_baset::output_xml(
 {
   xmlt program("program");
 
-  forall_goto_functions(f_it, goto_functions)
+  for(const auto &gf_entry : goto_functions.function_map)
   {
     xmlt function(
       "function",
-      {{"name", id2string(f_it->first)},
-       {"body_available", f_it->second.body_available() ? "true" : "false"}},
+      {{"name", id2string(gf_entry.first)},
+       {"body_available", gf_entry.second.body_available() ? "true" : "false"}},
       {});
 
-    if(f_it->second.body_available())
+    if(gf_entry.second.body_available())
     {
-      function.new_element(output_xml(ns, f_it->first, f_it->second.body));
+      function.new_element(
+        output_xml(ns, gf_entry.first, gf_entry.second.body));
     }
 
     program.new_element(function);
@@ -136,6 +138,8 @@ xmlt ai_baset::output_xml(
   const irep_idt &function_id,
   const goto_programt &goto_program) const
 {
+  (void)function_id; // unused parameter
+
   xmlt function_body;
 
   forall_goto_program_instructions(i_it, goto_program)
@@ -143,12 +147,12 @@ xmlt ai_baset::output_xml(
     xmlt location(
       "",
       {{"location_number", std::to_string(i_it->location_number)},
-       {"source_location", i_it->source_location.as_string()}},
+       {"source_location", i_it->source_location().as_string()}},
       {abstract_state_before(i_it)->output_xml(*this, ns)});
 
     // Ideally we need output_instruction_xml
     std::ostringstream out;
-    goto_program.output_instruction(ns, function_id, out, *i_it);
+    i_it->output(out);
     location.set_attribute("instruction", out.str());
 
     function_body.new_element(location);
@@ -195,8 +199,8 @@ void ai_baset::initialize(const irep_idt &, const goto_programt &goto_program)
 
 void ai_baset::initialize(const goto_functionst &goto_functions)
 {
-  forall_goto_functions(it, goto_functions)
-    initialize(it->first, it->second);
+  for(const auto &gf_entry : goto_functions.function_map)
+    initialize(gf_entry.first, gf_entry.second);
 }
 
 void ai_baset::finalize()
@@ -270,6 +274,10 @@ bool ai_baset::visit(
 {
   bool new_data=false;
   locationt l = p->current_location();
+  messaget log(message_handler);
+
+  log.progress() << "ai_baset::visit " << l->location_number << " in "
+                 << function_id << messaget::eom;
 
   // Function call and end are special cases
   if(l->is_function_call())
@@ -303,8 +311,14 @@ bool ai_baset::visit(
       if(to_l == goto_program.instructions.end())
         continue;
 
-      new_data |=
-        visit_edge(function_id, p, function_id, to_l, ns, working_set);
+      new_data |= visit_edge(
+        function_id,
+        p,
+        function_id,
+        to_l,
+        ai_history_baset::no_caller_history,
+        ns,
+        working_set); // Local steps so no caller history needed
     }
   }
 
@@ -316,13 +330,31 @@ bool ai_baset::visit_edge(
   trace_ptrt p,
   const irep_idt &to_function_id,
   locationt to_l,
+  trace_ptrt caller_history,
   const namespacet &ns,
   working_sett &working_set)
 {
+  messaget log(message_handler);
+  log.progress() << "ai_baset::visit_edge from "
+                 << p->current_location()->location_number << " to "
+                 << to_l->location_number << "... ";
+
   // Has history taught us not to step here...
-  auto next = p->step(to_l, *(storage->abstract_traces_before(to_l)));
+  auto next =
+    p->step(to_l, *(storage->abstract_traces_before(to_l)), caller_history);
   if(next.first == ai_history_baset::step_statust::BLOCKED)
+  {
+    log.progress() << "blocked by history" << messaget::eom;
     return false;
+  }
+  else if(next.first == ai_history_baset::step_statust::NEW)
+  {
+    log.progress() << "gives a new history... ";
+  }
+  else
+  {
+    log.progress() << "merges with existing history... ";
+  }
   trace_ptrt to_p = next.second;
 
   // Abstract domains are mutable so we must copy before we transform
@@ -332,21 +364,50 @@ bool ai_baset::visit_edge(
   statet &new_values = *tmp_state;
 
   // Apply transformer
+  log.progress() << "applying transformer... ";
   new_values.transform(function_id, p, to_function_id, to_p, *this, ns);
 
   // Expanding a domain means that it has to be analysed again
   // Likewise if the history insists that it is a new trace
   // (assuming it is actually reachable).
+  log.progress() << "merging... ";
+  bool return_value = false;
   if(
     merge(new_values, p, to_p) ||
     (next.first == ai_history_baset::step_statust::NEW &&
      !new_values.is_bottom()))
   {
     put_in_working_set(working_set, to_p);
-    return true;
+    log.progress() << "result queued." << messaget::eom;
+    return_value = true;
+  }
+  else
+  {
+    log.progress() << "domain unchanged." << messaget::eom;
   }
 
-  return false;
+  // Branch because printing some histories and domains can be expensive
+  // esp. if the output is then just discarded and this is a critical path.
+  if(message_handler.get_verbosity() >= messaget::message_levelt::M_DEBUG)
+  {
+    log.debug() << "p = ";
+    p->output(log.debug());
+    log.debug() << messaget::eom;
+
+    log.debug() << "current = ";
+    current.output(log.debug(), *this, ns);
+    log.debug() << messaget::eom;
+
+    log.debug() << "to_p = ";
+    to_p->output(log.debug());
+    log.debug() << messaget::eom;
+
+    log.debug() << "new_values = ";
+    new_values.output(log.debug(), *this, ns);
+    log.debug() << messaget::eom;
+  }
+
+  return return_value;
 }
 
 bool ai_baset::visit_edge_function_call(
@@ -359,6 +420,11 @@ bool ai_baset::visit_edge_function_call(
   const goto_functionst &,
   const namespacet &ns)
 {
+  messaget log(message_handler);
+  log.progress() << "ai_baset::visit_edge_function_call from "
+                 << p_call->current_location()->location_number << " to "
+                 << l_return->location_number << messaget::eom;
+
   // The default implementation is not interprocedural
   // so the effects of the call are approximated but nothing else
   return visit_edge(
@@ -366,6 +432,8 @@ bool ai_baset::visit_edge_function_call(
     p_call,
     calling_function_id,
     l_return,
+    ai_history_baset::
+      no_caller_history, // Not needed as we are skipping the function call
     ns,
     working_set);
 }
@@ -382,20 +450,25 @@ bool ai_baset::visit_function_call(
 
   PRECONDITION(l_call->is_function_call());
 
+  messaget log(message_handler);
+  log.progress() << "ai_baset::visit_function_call at "
+                 << l_call->location_number << messaget::eom;
+
   locationt l_return = std::next(l_call);
 
   // operator() allows analysis of a single goto_program independently
   // it generates a synthetic goto_functions object for this
   if(!goto_functions.function_map.empty())
   {
-    const code_function_callt &code = to_code_function_call(l_call->code);
-    const exprt &callee_expression = code.function();
+    const exprt &callee_expression = l_call->call_function();
 
     if(callee_expression.id() == ID_symbol)
     {
       const irep_idt &callee_function_id =
         to_symbol_expr(callee_expression).get_identifier();
 
+      log.progress() << "Calling " << callee_function_id << messaget::eom;
+
       goto_functionst::function_mapt::const_iterator it =
         goto_functions.function_map.find(callee_function_id);
 
@@ -439,6 +512,7 @@ bool ai_baset::visit_function_call(
     p_call,
     calling_function_id,
     l_return,
+    ai_history_baset::no_caller_history, // Would be the same as p_call...
     ns,
     working_set);
 }
@@ -454,6 +528,10 @@ bool ai_baset::visit_end_function(
   locationt l = p->current_location();
   PRECONDITION(l->is_end_function());
 
+  messaget log(message_handler);
+  log.progress() << "ai_baset::visit_end_function " << function_id
+                 << messaget::eom;
+
   // Do nothing
   return false;
 }
@@ -468,6 +546,11 @@ bool ai_recursive_interproceduralt::visit_edge_function_call(
   const goto_functionst &goto_functions,
   const namespacet &ns)
 {
+  messaget log(message_handler);
+  log.progress() << "ai_recursive_interproceduralt::visit_edge_function_call"
+                 << " from " << p_call->current_location()->location_number
+                 << " to " << l_return->location_number << messaget::eom;
+
   // This is the edge from call site to function head.
   {
     locationt l_begin = callee.instructions.begin();
@@ -480,9 +563,14 @@ bool ai_recursive_interproceduralt::visit_edge_function_call(
       p_call,
       callee_function_id,
       l_begin,
+      ai_history_baset::
+        no_caller_history, // Not needed as p_call already has the info
       ns,
       catch_working_set);
 
+    log.progress() << "Handle " << callee_function_id << " recursively"
+                   << messaget::eom;
+
     // do we need to do/re-do the fixedpoint of the body?
     if(new_data)
       fixedpoint(
@@ -495,6 +583,8 @@ bool ai_recursive_interproceduralt::visit_edge_function_call(
 
   // This is the edge from function end to return site.
   {
+    log.progress() << "Handle return edges" << messaget::eom;
+
     // get location at end of the procedure we have called
     locationt l_end = --callee.instructions.end();
     DATA_INVARIANT(
@@ -525,6 +615,7 @@ bool ai_recursive_interproceduralt::visit_edge_function_call(
           p_end,
           calling_function_id,
           l_return,
+          p_call, // To allow function-local history
           ns,
           working_set);
       }
