@@ -11,17 +11,17 @@ Author: Diffblue Ltd.
 #ifndef CPROVER_ANALYSES_DOES_REMOVE_CONST_H
 #define CPROVER_ANALYSES_DOES_REMOVE_CONST_H
 
-#include <util/type.h>
-#include <util/namespace.h>
+#include <utility>
 
 class goto_programt;
-class namespacet;
 class exprt;
+class source_locationt;
+class typet;
 
 class does_remove_constt
 {
 public:
-  does_remove_constt(const goto_programt &goto_program, const namespacet &ns);
+  explicit does_remove_constt(const goto_programt &);
   std::pair<bool, source_locationt>  operator()() const;
 
 private:
@@ -34,7 +34,6 @@ private:
     const typet *target_type, const typet *source_type) const;
 
   const goto_programt &goto_program;
-  const namespacet &ns;
 
   friend class does_remove_const_testt;
 };
