@@ -12,11 +12,9 @@ Author: Daniel Kroening, kroening@kroening.com
 
 #include "flow_insensitive_analysis.h"
 
-#include <cassert>
-
 #include <util/expr_util.h>
+#include <util/pointer_expr.h>
 #include <util/std_code.h>
-#include <util/std_expr.h>
 
 exprt flow_insensitive_abstract_domain_baset::get_guard(
   locationt from,
@@ -25,9 +23,9 @@ exprt flow_insensitive_abstract_domain_baset::get_guard(
   if(!from->is_goto())
     return true_exprt();
   else if(std::next(from) == to)
-    return boolean_negate(from->get_condition());
+    return boolean_negate(from->condition());
   else
-    return from->get_condition();
+    return from->condition();
 }
 
 exprt flow_insensitive_abstract_domain_baset::get_return_lhs(locationt to) const
@@ -39,7 +37,7 @@ exprt flow_insensitive_abstract_domain_baset::get_return_lhs(locationt to) const
     return static_cast<const exprt &>(get_nil_irep());
 
   // must be the function call
-  return to_code_function_call(to->code).lhs();
+  return to->call_lhs();
 }
 
 void flow_insensitive_analysis_baset::operator()(
@@ -61,11 +59,12 @@ void flow_insensitive_analysis_baset::output(
   const goto_functionst &goto_functions,
   std::ostream &out)
 {
-  forall_goto_functions(f_it, goto_functions)
+  for(const auto &gf_entry : goto_functions.function_map)
   {
-    out << "////\n" << "//// Function: " << f_it->first << "\n////\n\n";
+    out << "////\n"
+        << "//// Function: " << gf_entry.first << "\n////\n\n";
 
-    output(f_it->first, f_it->second.body, out);
+    output(gf_entry.first, gf_entry.second.body, out);
   }
 }
 
@@ -81,13 +80,13 @@ flow_insensitive_analysis_baset::locationt
 flow_insensitive_analysis_baset::get_next(
   working_sett &working_set)
 {
-  assert(!working_set.empty());
+  PRECONDITION(!working_set.empty());
 
-//  working_sett::iterator i=working_set.begin();
-//  locationt l=i->second;
-//  working_set.erase(i);
+  //  working_sett::iterator i=working_set.begin();
+  //  locationt l=i->second;
+  //  working_set.erase(i);
 
-//  pop_heap(working_set.begin(), working_set.end());
+  //  pop_heap(working_set.begin(), working_set.end());
   locationt l=working_set.top();
   working_set.pop();
 
@@ -153,13 +152,11 @@ bool flow_insensitive_analysis_baset::visit(
     if(l->is_function_call())
     {
       // this is a big special case
-      const code_function_callt &code = to_code_function_call(l->code);
-
       changed = do_function_call_rec(
         function_id,
         l,
-        code.function(),
-        code.arguments(),
+        l->call_function(),
+        l->call_arguments(),
         get_state(),
         goto_functions);
     }
@@ -176,16 +173,16 @@ bool flow_insensitive_analysis_baset::visit(
 //  if (id2string(l->function).find("debug")!=std::string::npos)
 //    std::cout << l->function << '\n'; //=="messages::debug")
 
-//  {
-//    static unsigned state_cntr=0;
-//    std::string s("pastate"); s += std::to_string(state_cntr);
-//    std::ofstream f(s.c_str());
-//    goto_program.output_instruction(ns, "", f, l);
-//    f << '\n';
-//    get_state().output(ns, f);
-//    f.close();
-//    state_cntr++;
-//  }
+  //  {
+  //    static unsigned state_cntr=0;
+  //    std::string s("pastate"); s += std::to_string(state_cntr);
+  //    std::ofstream f(s.c_str());
+  //    l->output(f);
+  //    f << '\n';
+  //    get_state().output(ns, f);
+  //    f.close();
+  //    state_cntr++;
+  //  }
 
   return new_data;
 }
@@ -202,12 +199,11 @@ bool flow_insensitive_analysis_baset::do_function_call(
 
   if(!goto_function.body_available())
   {
-    const code_function_callt &code = to_code_function_call(l_call->code);
-
     goto_programt temp;
 
-    goto_programt::targett r = temp.add(goto_programt::make_return(code_returnt(
-      side_effect_expr_nondett(code.lhs().type(), l_call->source_location))));
+    goto_programt::targett r =
+      temp.add(goto_programt::make_set_return_value(side_effect_expr_nondett(
+        l_call->call_lhs().type(), l_call->source_location())));
     r->location_number=0;
 
     goto_programt::targett t = temp.add(goto_programt::make_end_function());
@@ -227,7 +223,8 @@ bool flow_insensitive_analysis_baset::do_function_call(
     return new_data;
   }
 
-  assert(!goto_function.body.instructions.empty());
+  DATA_INVARIANT(
+    !goto_function.body.instructions.empty(), "body must be present");
 
   bool new_data=false;
 
@@ -260,7 +257,7 @@ bool flow_insensitive_analysis_baset::do_function_call(
     // get location at end of procedure
     locationt l_end=--goto_function.body.instructions.end();
 
-    assert(l_end->is_end_function());
+    DATA_INVARIANT(l_end->is_end_function(), "must be end of function");
 
     // do edge from end of function to instruction after call
     locationt l_next=l_call;
@@ -384,20 +381,14 @@ void flow_insensitive_analysis_baset::fixedpoint(
 {
   // do each function at least once
 
-  forall_goto_functions(it, goto_functions)
-    if(functions_done.find(it->first)==
-       functions_done.end())
+  for(const auto &gf_entry : goto_functions.function_map)
+  {
+    if(functions_done.find(gf_entry.first) == functions_done.end())
     {
-      fixedpoint(it, goto_functions);
+      functions_done.insert(gf_entry.first);
+      fixedpoint(gf_entry.first, gf_entry.second.body, goto_functions);
     }
-}
-
-bool flow_insensitive_analysis_baset::fixedpoint(
-  const goto_functionst::function_mapt::const_iterator it,
-  const goto_functionst &goto_functions)
-{
-  functions_done.insert(it->first);
-  return fixedpoint(it->first, it->second.body, goto_functions);
+  }
 }
 
 void flow_insensitive_analysis_baset::update(const goto_functionst &)
