@@ -57,26 +57,29 @@ void interval_domaint::output(
 }
 
 void interval_domaint::transform(
-  const irep_idt &,
-  locationt from,
-  const irep_idt &,
-  locationt to,
-  ai_baset &,
+  const irep_idt &function_from,
+  trace_ptrt trace_from,
+  const irep_idt &function_to,
+  trace_ptrt trace_to,
+  ai_baset &ai,
   const namespacet &ns)
 {
+  locationt from{trace_from->current_location()};
+  locationt to{trace_to->current_location()};
+
   const goto_programt::instructiont &instruction=*from;
-  switch(instruction.type)
+  switch(instruction.type())
   {
   case DECL:
-    havoc_rec(to_code_decl(instruction.code).symbol());
+    havoc_rec(instruction.decl_symbol());
     break;
 
   case DEAD:
-    havoc_rec(to_code_dead(instruction.code).symbol());
+    havoc_rec(instruction.dead_symbol());
     break;
 
   case ASSIGN:
-    assign(to_code_assign(instruction.code));
+    assign(instruction.assign_lhs(), instruction.assign_rhs());
     break;
 
   case GOTO:
@@ -88,23 +91,22 @@ void interval_domaint::transform(
     if(from->get_target() != next) // If equal then a skip
     {
       if(next == to)
-        assume(not_exprt(instruction.get_condition()), ns);
+        assume(not_exprt(instruction.condition()), ns);
       else
-        assume(instruction.get_condition(), ns);
+        assume(instruction.condition(), ns);
     }
     break;
   }
 
   case ASSUME:
-    assume(instruction.get_condition(), ns);
+    assume(instruction.condition(), ns);
     break;
 
   case FUNCTION_CALL:
   {
-    const code_function_callt &code_function_call =
-      to_code_function_call(instruction.code);
-    if(code_function_call.lhs().is_not_nil())
-      havoc_rec(code_function_call.lhs());
+    const auto &lhs = instruction.call_lhs();
+    if(lhs.is_not_nil())
+      havoc_rec(lhs);
     break;
   }
 
@@ -112,8 +114,8 @@ void interval_domaint::transform(
   case THROW:
     DATA_INVARIANT(false, "Exceptions must be removed before analysis");
     break;
-  case RETURN:
-    DATA_INVARIANT(false, "Returns must be removed before analysis");
+  case SET_RETURN_VALUE:
+    DATA_INVARIANT(false, "SET_RETURN_VALUE must be removed before analysis");
     break;
   case ATOMIC_BEGIN: // Ignoring is a valid over-approximation
   case ATOMIC_END:   // Ignoring is a valid over-approximation
@@ -206,10 +208,10 @@ bool interval_domaint::join(
   return result;
 }
 
-void interval_domaint::assign(const code_assignt &code_assign)
+void interval_domaint::assign(const exprt &lhs, const exprt &rhs)
 {
-  havoc_rec(code_assign.lhs());
-  assume_rec(code_assign.lhs(), ID_equal, code_assign.rhs());
+  havoc_rec(lhs);
+  assume_rec(lhs, ID_equal, rhs);
 }
 
 void interval_domaint::havoc_rec(const exprt &lhs)
@@ -262,15 +264,15 @@ void interval_domaint::assume_rec(
   // we now have lhs <  rhs or
   //             lhs <= rhs
 
-  assert(id==ID_lt || id==ID_le);
+  DATA_INVARIANT(id == ID_lt || id == ID_le, "unexpected comparison operator");
 
-  #ifdef DEBUG
+#ifdef DEBUG
   std::cout << "assume_rec: "
             << from_expr(lhs) << " " << id << " "
             << from_expr(rhs) << "\n";
   #endif
 
-  if(lhs.id()==ID_symbol && rhs.id()==ID_constant)
+  if(lhs.id() == ID_symbol && rhs.is_constant())
   {
     irep_idt lhs_identifier=to_symbol_expr(lhs).get_identifier();
 
@@ -295,7 +297,7 @@ void interval_domaint::assume_rec(
         make_bottom();
     }
   }
-  else if(lhs.id()==ID_constant && rhs.id()==ID_symbol)
+  else if(lhs.is_constant() && rhs.id() == ID_symbol)
   {
     irep_idt rhs_identifier=to_symbol_expr(rhs).get_identifier();
 
@@ -329,10 +331,10 @@ void interval_domaint::assume_rec(
     {
       integer_intervalt &lhs_i=int_map[lhs_identifier];
       integer_intervalt &rhs_i=int_map[rhs_identifier];
-      lhs_i.meet(rhs_i);
-      rhs_i=lhs_i;
-      if(rhs_i.is_bottom())
-        make_bottom();
+      if(id == ID_lt && !lhs_i.is_less_than(rhs_i))
+        lhs_i.make_less_than(rhs_i);
+      if(id == ID_le && !lhs_i.is_less_than_eq(rhs_i))
+        lhs_i.make_less_than_eq(rhs_i);
     }
     else if(is_float(lhs.type()) && is_float(rhs.type()))
     {
@@ -388,14 +390,18 @@ void interval_domaint::assume_rec(
   else if(cond.id()==ID_and)
   {
     if(!negation)
-      forall_operands(it, cond)
-        assume_rec(*it, false);
+    {
+      for(const auto &op : cond.operands())
+        assume_rec(op, false);
+    }
   }
   else if(cond.id()==ID_or)
   {
     if(negation)
-      forall_operands(it, cond)
-        assume_rec(*it, true);
+    {
+      for(const auto &op : cond.operands())
+        assume_rec(op, true);
+    }
   }
 }
 
