@@ -11,18 +11,21 @@ Author: Daniel Kroening, kroening@kroening.com
 #include <util/arith_tools.h>
 #include <util/c_types.h>
 #include <util/config.h>
-#include <util/string_constant.h>
+#include <util/message.h>
+#include <util/pointer_expr.h>
+#include <util/symbol_table_base.h>
 
 #include <goto-programs/goto_functions.h>
 
 #include <linking/static_lifetime_init.h>
 
 #include "c_nondet_symbol_factory.h"
+#include "expr2c.h"
 
 exprt::operandst build_function_environment(
   const code_typet::parameterst &parameters,
   code_blockt &init_code,
-  symbol_tablet &symbol_table,
+  symbol_table_baset &symbol_table,
   const c_object_factory_parameterst &object_factory_parameters)
 {
   exprt::operandst main_arguments;
@@ -52,7 +55,7 @@ exprt::operandst build_function_environment(
 void record_function_outputs(
   const symbolt &function,
   code_blockt &init_code,
-  symbol_tablet &symbol_table)
+  symbol_table_baset &symbol_table)
 {
   bool has_return_value =
     to_code_type(function.type).return_type() != void_type();
@@ -100,7 +103,7 @@ void record_function_outputs(
 }
 
 bool ansi_c_entry_point(
-  symbol_tablet &symbol_table,
+  symbol_table_baset &symbol_table,
   message_handlert &message_handler,
   const c_object_factory_parameterst &object_factory_parameters)
 {
@@ -114,20 +117,14 @@ bool ansi_c_entry_point(
   // find main symbol, if any is given
   if(config.main.has_value())
   {
-    std::list<irep_idt> matches;
+    auto matches = symbol_table.match_name_or_base_name(*config.main);
 
-    forall_symbol_base_map(
-      it, symbol_table.symbol_base_map, config.main.value())
+    for(auto it = matches.begin(); it != matches.end();) // no ++it
     {
-      // look it up
-      symbol_tablet::symbolst::const_iterator s_it=
-        symbol_table.symbols.find(it->second);
-
-      if(s_it==symbol_table.symbols.end())
-        continue;
-
-      if(s_it->second.type.id()==ID_code)
-        matches.push_back(it->second);
+      if((*it)->second.type.id() != ID_code || (*it)->second.is_property)
+        it = matches.erase(it);
+      else
+        ++it;
     }
 
     if(matches.empty())
@@ -146,13 +143,13 @@ bool ansi_c_entry_point(
       return true;
     }
 
-    main_symbol=matches.front();
+    main_symbol = matches.front()->first;
   }
   else
     main_symbol=ID_main;
 
   // look it up
-  symbol_tablet::symbolst::const_iterator s_it=
+  symbol_table_baset::symbolst::const_iterator s_it =
     symbol_table.symbols.find(main_symbol);
 
   if(s_it==symbol_table.symbols.end())
@@ -186,7 +183,7 @@ bool ansi_c_entry_point(
 /// \return Returns false if the _start method was generated correctly
 bool generate_ansi_c_start_function(
   const symbolt &symbol,
-  symbol_tablet &symbol_table,
+  symbol_table_baset &symbol_table,
   message_handlert &message_handler,
   const c_object_factory_parameterst &object_factory_parameters)
 {
@@ -199,7 +196,7 @@ bool generate_ansi_c_start_function(
   // build call to initialization function
 
   {
-    symbol_tablet::symbolst::const_iterator init_it=
+    symbol_table_baset::symbolst::const_iterator init_it =
       symbol_table.symbols.find(INITIALIZE_FUNCTION);
 
     if(init_it==symbol_table.symbols.end())
@@ -244,19 +241,24 @@ bool generate_ansi_c_start_function(
     {
       // ok
     }
-    else if(parameters.size()==2 || parameters.size()==3)
+    // The C standard (and any related architecture descriptions) enforces an
+    // order of parameters. The user, however, may supply arbitrary
+    // (syntactically valid) C code, even one that does not respect the calling
+    // conventions set out in the C standard. If the user does supply such code,
+    // then we can only tell them that they got it wrong, which is what we do
+    // via the error message in the else branch of this code.
+    else if(
+      parameters.size() >= 2 && parameters[1].type().id() == ID_pointer &&
+      (parameters.size() == 2 ||
+       (parameters.size() == 3 && parameters[2].type().id() == ID_pointer)))
     {
       namespacet ns(symbol_table);
 
       {
-        symbolt argc_symbol;
-
+        symbolt argc_symbol{"argc'", signed_int_type(), ID_C};
         argc_symbol.base_name = "argc'";
-        argc_symbol.name = "argc'";
-        argc_symbol.type = signed_int_type();
         argc_symbol.is_static_lifetime = true;
         argc_symbol.is_lvalue = true;
-        argc_symbol.mode = ID_C;
 
         auto r = symbol_table.insert(argc_symbol);
         if(!r.second && r.first != argc_symbol)
@@ -278,14 +280,10 @@ bool generate_ansi_c_start_function(
         const plus_exprt size_expr(argc_symbol.symbol_expr(), one_expr);
         const array_typet argv_type(pointer_type(char_type()), size_expr);
 
-        symbolt argv_symbol;
-
+        symbolt argv_symbol{"argv'", argv_type, ID_C};
         argv_symbol.base_name = "argv'";
-        argv_symbol.name = "argv'";
-        argv_symbol.type = argv_type;
         argv_symbol.is_static_lifetime = true;
         argv_symbol.is_lvalue = true;
-        argv_symbol.mode = ID_C;
 
         auto r = symbol_table.insert(argv_symbol);
         if(!r.second && r.first != argv_symbol)
@@ -298,23 +296,26 @@ bool generate_ansi_c_start_function(
       }
 
       const symbolt &argv_symbol=ns.lookup("argv'");
+      const array_typet &argv_array_type = to_array_type(argv_symbol.type);
 
       {
-        // assume argc is at least one
-        exprt one=from_integer(1, argc_symbol.type);
+        // Assume argc is at least zero. Note that we don't assume it's
+        // at least one, since this isn't guaranteed, as exemplified by
+        // https://www.qualys.com/2022/01/25/cve-2021-4034/pwnkit.txt
+        // The C standard only guarantees "The value of argc shall be
+        // nonnegative." and "argv[argc] shall be a null pointer."
+        exprt zero = from_integer(0, argc_symbol.type);
 
         binary_relation_exprt ge(
-          argc_symbol.symbol_expr(), ID_ge, std::move(one));
+          argc_symbol.symbol_expr(), ID_ge, std::move(zero));
 
         init_code.add(code_assumet(std::move(ge)));
       }
 
+      if(config.ansi_c.max_argc.has_value())
       {
-        // assume argc is at most MAX/8-1
-        mp_integer upper_bound=
-          power(2, config.ansi_c.int_width-4);
-
-        exprt bound_expr=from_integer(upper_bound, argc_symbol.type);
+        exprt bound_expr =
+          from_integer(*config.ansi_c.max_argc, argc_symbol.type);
 
         binary_relation_exprt le(
           argc_symbol.symbol_expr(), ID_le, std::move(bound_expr));
@@ -328,12 +329,9 @@ bool generate_ansi_c_start_function(
       if(parameters.size()==3)
       {
         {
-          symbolt envp_size_symbol;
+          symbolt envp_size_symbol{"envp_size'", size_type(), ID_C};
           envp_size_symbol.base_name = "envp_size'";
-          envp_size_symbol.name = "envp_size'";
-          envp_size_symbol.type = size_type();
           envp_size_symbol.is_static_lifetime = true;
-          envp_size_symbol.mode = ID_C;
 
           if(!symbol_table.insert(std::move(envp_size_symbol)).second)
           {
@@ -347,13 +345,13 @@ bool generate_ansi_c_start_function(
         const symbolt &envp_size_symbol=ns.lookup("envp_size'");
 
         {
-          symbolt envp_symbol;
+          symbolt envp_symbol{
+            "envp'",
+            array_typet(
+              pointer_type(char_type()), envp_size_symbol.symbol_expr()),
+            ID_C};
           envp_symbol.base_name = "envp'";
-          envp_symbol.name = "envp'";
-          envp_symbol.type = array_typet(
-            pointer_type(char_type()), envp_size_symbol.symbol_expr());
           envp_symbol.is_static_lifetime = true;
-          envp_symbol.mode = ID_C;
 
           if(!symbol_table.insert(std::move(envp_symbol)).second)
           {
@@ -399,33 +397,40 @@ bool generate_ansi_c_start_function(
       {
         // assign argv[argc] to NULL
         const null_pointer_exprt null(
-          to_pointer_type(argv_symbol.type.subtype()));
+          to_pointer_type(argv_array_type.element_type()));
 
         index_exprt index_expr(
-          argv_symbol.symbol_expr(), argc_symbol.symbol_expr());
+          argv_symbol.symbol_expr(),
+          typecast_exprt::conditional_cast(
+            argc_symbol.symbol_expr(), argv_array_type.index_type()));
 
+        init_code.add(code_frontend_assignt(index_expr, null));
         // disable bounds check on that one
-        index_expr.set("bounds_check", false);
-
-        init_code.add(code_assignt(index_expr, null));
+        init_code.statements().back().add_source_location().add_pragma(
+          "disable:bounds-check");
       }
 
       if(parameters.size()==3)
       {
         const symbolt &envp_symbol=ns.lookup("envp'");
+        const array_typet &envp_array_type = to_array_type(envp_symbol.type);
         const symbolt &envp_size_symbol=ns.lookup("envp_size'");
 
         // assume envp[envp_size] is NULL
-        null_pointer_exprt null(to_pointer_type(envp_symbol.type.subtype()));
+        null_pointer_exprt null(
+          to_pointer_type(envp_array_type.element_type()));
 
         index_exprt index_expr(
-          envp_symbol.symbol_expr(), envp_size_symbol.symbol_expr());
-        // disable bounds check on that one
-        index_expr.set("bounds_check", false);
+          envp_symbol.symbol_expr(),
+          typecast_exprt::conditional_cast(
+            envp_size_symbol.symbol_expr(), envp_array_type.index_type()));
 
         equal_exprt is_null(std::move(index_expr), std::move(null));
 
         init_code.add(code_assumet(is_null));
+        // disable bounds check on that one
+        init_code.statements().back().add_source_location().add_pragma(
+          "disable:bounds-check");
       }
 
       {
@@ -444,10 +449,10 @@ bool generate_ansi_c_start_function(
 
         {
           index_exprt index_expr(
-            argv_symbol.symbol_expr(), from_integer(0, index_type()));
-
+            argv_symbol.symbol_expr(),
+            from_integer(0, argv_array_type.index_type()));
           // disable bounds check on that one
-          index_expr.set("bounds_check", false);
+          index_expr.add_source_location().add_pragma("disable:bounds-check");
 
           const pointer_typet &pointer_type =
             to_pointer_type(parameters[1].type());
@@ -460,9 +465,11 @@ bool generate_ansi_c_start_function(
         if(parameters.size()==3)
         {
           const symbolt &envp_symbol=ns.lookup("envp'");
+          const array_typet &envp_array_type = to_array_type(envp_symbol.type);
 
           index_exprt index_expr(
-            envp_symbol.symbol_expr(), from_integer(0, index_type()));
+            envp_symbol.symbol_expr(),
+            from_integer(0, envp_array_type.index_type()));
 
           const pointer_typet &pointer_type =
             to_pointer_type(parameters[2].type());
@@ -473,7 +480,23 @@ bool generate_ansi_c_start_function(
       }
     }
     else
-      UNREACHABLE;
+    {
+      const namespacet ns{symbol_table};
+      const std::string main_signature = type2c(symbol.type, ns);
+      messaget message(message_handler);
+      message.error().source_location = symbol.location;
+      message.error() << "'main' with signature '" << main_signature
+                      << "' found,"
+                      << " but expecting one of:\n"
+                      << "   int main(void)\n"
+                      << "   int main(int argc, char *argv[])\n"
+                      << "   int main(int argc, char *argv[], char *envp[])\n"
+                      << "If this is a non-standard main entry point please "
+                         "provide a custom\n"
+                      << "entry function and use --function instead"
+                      << messaget::eom;
+      return true;
+    }
   }
   else
   {
@@ -488,13 +511,31 @@ bool generate_ansi_c_start_function(
 
   record_function_outputs(symbol, init_code, symbol_table);
 
-  // add the entry point symbol
-  symbolt new_symbol;
+  // now call destructor functions (a GCC extension)
 
-  new_symbol.name=goto_functionst::entry_point();
-  new_symbol.type = code_typet({}, void_type());
+  for(const auto &symbol_table_entry : symbol_table.symbols)
+  {
+    const symbolt &symbol = symbol_table_entry.second;
+
+    if(symbol.type.id() != ID_code)
+      continue;
+
+    const code_typet &code_type = to_code_type(symbol.type);
+    if(
+      code_type.return_type().id() == ID_destructor &&
+      code_type.parameters().empty())
+    {
+      code_function_callt destructor_call(symbol.symbol_expr());
+      destructor_call.add_source_location() = symbol.location;
+      init_code.add(std::move(destructor_call));
+    }
+  }
+
+  // add the entry point symbol
+  symbolt new_symbol{
+    goto_functionst::entry_point(), code_typet{{}, void_type()}, symbol.mode};
+  new_symbol.base_name = goto_functionst::entry_point();
   new_symbol.value.swap(init_code);
-  new_symbol.mode=symbol.mode;
 
   if(!symbol_table.insert(std::move(new_symbol)).second)
   {
