@@ -13,7 +13,6 @@ Author: Daniel Kroening, kroening@kroening.com
 #include <util/c_types.h>
 #include <util/config.h>
 #include <util/cprover_prefix.h>
-#include <util/expr_util.h>
 #include <util/find_symbols.h>
 #include <util/fixedbv.h>
 #include <util/floatbv_expr.h>
@@ -213,16 +212,16 @@ void expr2ct::get_shorthands(const exprt &expr)
 
 std::string expr2ct::convert(const typet &src)
 {
-  return convert_rec(src, c_qualifierst(), "");
+  return convert_with_identifier(src, "");
 }
 
 std::string expr2ct::convert_rec(
   const typet &src,
-  const qualifierst &qualifiers,
+  const c_qualifierst &qualifiers,
   const std::string &declarator)
 {
-  std::unique_ptr<qualifierst> clone = qualifiers.clone();
-  c_qualifierst &new_qualifiers = dynamic_cast<c_qualifierst &>(*clone);
+  std::unique_ptr<c_qualifierst> clone = qualifiers.clone();
+  c_qualifierst &new_qualifiers = *clone;
   new_qualifiers.read(src);
 
   std::string q=new_qualifiers.as_string();
@@ -379,7 +378,7 @@ std::string expr2ct::convert_rec(
       for(const auto &c : union_type.components())
       {
         dest += ' ';
-        dest += convert_rec(c.type(), c_qualifierst(), id2string(c.get_name()));
+        dest += convert_with_identifier(c.type(), id2string(c.get_name()));
         dest += ';';
       }
 
@@ -538,7 +537,7 @@ std::string expr2ct::convert_rec(
         {
           std::string arg_declarator=
             convert(symbol_exprt(it->get_identifier(), it->type()));
-          dest+=convert_rec(it->type(), c_qualifierst(), arg_declarator);
+          dest += convert_with_identifier(it->type(), arg_declarator);
         }
       }
 
@@ -692,10 +691,8 @@ std::string expr2ct::convert_struct_type(
       }
 
       dest+=' ';
-      dest+=convert_rec(
-        component.type(),
-        c_qualifierst(),
-        id2string(component.get_name()));
+      dest += convert_with_identifier(
+        component.type(), id2string(component.get_name()));
       dest+=';';
     }
 
@@ -715,7 +712,7 @@ std::string expr2ct::convert_struct_type(
 /// \return A C-like type declaration of an array
 std::string expr2ct::convert_array_type(
   const typet &src,
-  const qualifierst &qualifiers,
+  const c_qualifierst &qualifiers,
   const std::string &declarator_str)
 {
   return convert_array_type(
@@ -732,7 +729,7 @@ std::string expr2ct::convert_array_type(
 /// \return A C-like type declaration of an array
 std::string expr2ct::convert_array_type(
   const typet &src,
-  const qualifierst &qualifiers,
+  const c_qualifierst &qualifiers,
   const std::string &declarator_str,
   bool inc_size_if_possible)
 {
@@ -890,13 +887,11 @@ std::string expr2ct::convert_with(
       const irep_idt &component_name=
         src.operands()[i].get(ID_component_name);
 
-      const typet &full_type = ns.follow(old.type());
-
-      const struct_union_typet &struct_union_type=
-        to_struct_union_type(full_type);
-
-      const struct_union_typet::componentt &comp_expr=
-        struct_union_type.get_component(component_name);
+      const struct_union_typet::componentt &comp_expr =
+        (old.type().id() == ID_struct_tag || old.type().id() == ID_union_tag)
+          ? ns.follow_tag(to_struct_or_union_tag_type(old.type()))
+              .get_component(component_name)
+          : to_struct_union_type(old.type()).get_component(component_name);
       CHECK_RETURN(comp_expr.is_not_nil());
 
       irep_idt display_component_name;
@@ -1551,26 +1546,31 @@ std::string expr2ct::convert_member(
     dest+='.';
   }
 
-  const typet &full_type = ns.follow(compound.type());
-
-  if(full_type.id()!=ID_struct &&
-     full_type.id()!=ID_union)
+  if(
+    compound.type().id() != ID_struct && compound.type().id() != ID_union &&
+    compound.type().id() != ID_struct_tag &&
+    compound.type().id() != ID_union_tag)
+  {
     return convert_norep(src, precedence);
+  }
 
-  const struct_union_typet &struct_union_type=
-    to_struct_union_type(full_type);
+  const struct_union_typet &struct_union_type =
+    (compound.type().id() == ID_struct_tag ||
+     compound.type().id() == ID_union_tag)
+      ? ns.follow_tag(to_struct_or_union_tag_type(compound.type()))
+      : to_struct_union_type(compound.type());
 
   irep_idt component_name=src.get_component_name();
 
   if(!component_name.empty())
   {
-    const exprt &comp_expr = struct_union_type.get_component(component_name);
+    const auto &comp_expr = struct_union_type.get_component(component_name);
 
     if(comp_expr.is_nil())
       return convert_norep(src, precedence);
 
-    if(!comp_expr.get(ID_pretty_name).empty())
-      dest+=comp_expr.get_string(ID_pretty_name);
+    if(!comp_expr.get_pretty_name().empty())
+      dest += id2string(comp_expr.get_pretty_name());
     else
       dest+=id2string(component_name);
 
@@ -1582,9 +1582,12 @@ std::string expr2ct::convert_member(
   if(n>=struct_union_type.components().size())
     return convert_norep(src, precedence);
 
-  const exprt &comp_expr = struct_union_type.components()[n];
+  const auto &comp_expr = struct_union_type.components()[n];
 
-  dest+=comp_expr.get_string(ID_pretty_name);
+  if(!comp_expr.get_pretty_name().empty())
+    dest += id2string(comp_expr.get_pretty_name());
+  else
+    dest += id2string(comp_expr.get_name());
 
   return dest;
 }
@@ -1647,7 +1650,7 @@ std::string expr2ct::convert_symbol(const exprt &src)
     dest=id2string(entry->second);
 
     #if 0
-    if(has_prefix(id2string(id), SYMEX_DYNAMIC_PREFIX "::dynamic_object"))
+    if(id.starts_with(SYMEX_DYNAMIC_PREFIX "::dynamic_object"))
     {
       if(sizeof_nesting++ == 0)
         dest+=" /*"+convert(src.type());
@@ -1719,7 +1722,7 @@ std::string expr2ct::convert_object_descriptor(
   return result;
 }
 
-static optionalt<exprt>
+static std::optional<exprt>
 build_sizeof_expr(const constant_exprt &expr, const namespacet &ns)
 {
   const typet &type = static_cast<const typet &>(expr.find(ID_C_c_sizeof_type));
@@ -1728,7 +1731,7 @@ build_sizeof_expr(const constant_exprt &expr, const namespacet &ns)
     return {};
 
   const auto type_size_expr = size_of_expr(type, ns);
-  optionalt<mp_integer> type_size;
+  std::optional<mp_integer> type_size;
   if(type_size_expr.has_value())
     type_size = numeric_cast<mp_integer>(*type_size_expr);
   auto val = numeric_cast<mp_integer>(expr);
@@ -1979,7 +1982,7 @@ std::string expr2ct::convert_constant(
   }
   else if(type.id()==ID_pointer)
   {
-    if(is_null_pointer(src))
+    if(src.is_null_pointer())
     {
       if(configuration.use_library_macros)
         dest = "NULL";
@@ -1989,7 +1992,7 @@ std::string expr2ct::convert_constant(
         dest="(("+convert(type)+")"+dest+")";
     }
     else if(
-      value == "INVALID" || has_prefix(id2string(value), "INVALID-") ||
+      value == "INVALID" || value.starts_with("INVALID-") ||
       value == "NULL+offset")
     {
       dest = id2string(value);
@@ -2053,13 +2056,13 @@ std::string expr2ct::convert_struct(
   unsigned &precedence,
   bool include_padding_components)
 {
-  const typet full_type=ns.follow(src.type());
-
-  if(full_type.id()!=ID_struct)
+  if(src.type().id() != ID_struct && src.type().id() != ID_struct_tag)
     return convert_norep(src, precedence);
 
-  const struct_typet &struct_type=
-    to_struct_type(full_type);
+  const struct_typet &struct_type =
+    src.type().id() == ID_struct_tag
+      ? ns.follow_tag(to_struct_tag_type(src.type()))
+      : to_struct_type(src.type());
 
   const struct_typet::componentst &components=
     struct_type.components();
@@ -2844,7 +2847,7 @@ expr2ct::convert_code_frontend_decl(const codet &src, unsigned indent)
       dest+="inline ";
   }
 
-  dest+=convert_rec(src.op0().type(), c_qualifierst(), declarator);
+  dest += convert_with_identifier(src.op0().type(), declarator);
 
   if(src.operands().size()==2)
     dest+="="+convert(src.op1());
@@ -3491,9 +3494,18 @@ expr2ct::convert_extractbits(const extractbits_exprt &src, unsigned precedence)
 {
   std::string dest = convert_with_precedence(src.src(), precedence);
   dest+='[';
-  dest += convert_with_precedence(src.upper(), precedence);
+  auto expr_width_opt = pointer_offset_bits(src.type(), ns);
+  if(expr_width_opt.has_value())
+  {
+    auto upper = plus_exprt{
+      src.index(),
+      from_integer(expr_width_opt.value() - 1, src.index().type())};
+    dest += convert_with_precedence(upper, precedence);
+  }
+  else
+    dest += "?";
   dest+=", ";
-  dest += convert_with_precedence(src.lower(), precedence);
+  dest += convert_with_precedence(src.index(), precedence);
   dest+=']';
 
   return dest;
@@ -3726,10 +3738,10 @@ std::string expr2ct::convert_with_precedence(
       "__builtin_bswap" + integer2string(*pointer_offset_bits(
                             to_unary_expr(src).op().type(), ns)));
 
-  else if(has_prefix(src.id_string(), "byte_extract"))
+  else if(src.id().starts_with("byte_extract"))
     return convert_byte_extract(to_byte_extract_expr(src), precedence = 16);
 
-  else if(has_prefix(src.id_string(), "byte_update"))
+  else if(src.id().starts_with("byte_update"))
     return convert_byte_update(to_byte_update_expr(src), precedence = 16);
 
   else if(src.id()==ID_address_of)
@@ -3957,8 +3969,7 @@ std::string expr2ct::convert_with_precedence(
   }
 
   else if(src.id()==ID_string_constant)
-    return '"' + MetaString(id2string(to_string_constant(src).get_value())) +
-           '"';
+    return '"' + MetaString(id2string(to_string_constant(src).value())) + '"';
 
   else if(src.id()==ID_struct)
     return convert_struct(src, precedence);
@@ -4066,7 +4077,7 @@ std::string expr2ct::convert_with_precedence(
   return convert_norep(src, precedence);
 }
 
-optionalt<std::string> expr2ct::convert_function(const exprt &src)
+std::optional<std::string> expr2ct::convert_function(const exprt &src)
 {
   static const std::map<irep_idt, std::string> function_names = {
     {"buffer_size", "BUFFER_SIZE"},
