@@ -27,6 +27,7 @@ Author: Daniel Kroening, kroening@kroening.com
 
 #include <langapi/language_util.h>
 
+#include "destructor.h"
 #include "format_strings.h"
 
 void goto_convertt::do_prob_uniform(
@@ -400,6 +401,7 @@ void goto_convertt::do_cpp_new(
   bool new_array = rhs.get(ID_statement) == ID_cpp_new_array;
 
   exprt count;
+  clean_expr_resultt side_effects;
 
   if(new_array)
   {
@@ -407,7 +409,8 @@ void goto_convertt::do_cpp_new(
       static_cast<const exprt &>(rhs.find(ID_size)), object_size.type());
 
     // might have side-effect
-    clean_expr(count, dest, ID_cpp);
+    side_effects.add(clean_expr(count, ID_cpp));
+    dest.destructive_append(side_effects.side_effects);
   }
 
   exprt tmp_symbol_expr;
@@ -493,6 +496,9 @@ void goto_convertt::do_cpp_new(
     typecast_exprt(tmp_symbol_expr, lhs.type()),
     rhs.find_source_location()));
 
+  side_effects.add_temporary(to_symbol_expr(tmp_symbol_expr).get_identifier());
+  destruct_locals(side_effects.temporaries, dest, ns);
+
   // grab initializer
   goto_programt tmp_initializer;
   cpp_new_initializer(lhs, rhs, tmp_initializer);
@@ -685,6 +691,8 @@ void goto_convertt::do_havoc_slice(
 
   codet array_replace(ID_array_replace, {arg0, arg1}, source_location);
   dest.add(goto_programt::make_other(array_replace, source_location));
+
+  destruct_locals({nondet_contents.name}, dest, ns);
 }
 
 /// alloca allocates memory that is freed when leaving the function (and not the
@@ -773,6 +781,9 @@ void goto_convertt::do_alloca(
   dest.add(goto_programt::make_assignment(
     this_alloca_ptr, std::move(rhs), source_location));
 
+  if(lhs.is_nil())
+    destruct_locals({to_symbol_expr(new_lhs).get_identifier()}, dest, ns);
+
   // mark pointer to alloca result as dead, unless the alloca result (in
   // this_alloca_ptr)  is still NULL
   symbol_exprt dead_object_sym =
