@@ -5,9 +5,9 @@
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-int __VERIFIER_nondet_int();
+int __VERIFIER_nondet_int(void);
 
-inline int pthread_mutexattr_settype(pthread_mutexattr_t *attr, int type)
+int pthread_mutexattr_settype(pthread_mutexattr_t *attr, int type)
 {
   __CPROVER_HIDE:;
 
@@ -30,9 +30,9 @@ inline int pthread_mutexattr_settype(pthread_mutexattr_t *attr, int type)
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-int __VERIFIER_nondet_int();
+int __VERIFIER_nondet_int(void);
 
-inline int pthread_cancel(pthread_t thread)
+int pthread_cancel(pthread_t thread)
 {
   __CPROVER_HIDE:;
 
@@ -64,7 +64,7 @@ typedef signed char __CPROVER_mutex_t;
 #endif
 
 #ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS
-inline void pthread_mutex_cleanup(void *p)
+void pthread_mutex_cleanup(void *p)
 {
   __CPROVER_HIDE:;
   __CPROVER_assert(
@@ -73,8 +73,9 @@ inline void pthread_mutex_cleanup(void *p)
 }
 #endif
 
-inline int pthread_mutex_init(
-  pthread_mutex_t *mutex, const pthread_mutexattr_t *mutexattr)
+int pthread_mutex_init(
+  pthread_mutex_t *mutex,
+  const pthread_mutexattr_t *mutexattr)
 {
   __CPROVER_HIDE:;
   *((__CPROVER_mutex_t *)mutex)=0;
@@ -108,7 +109,7 @@ typedef signed char __CPROVER_mutex_t;
 #endif
 #endif
 
-inline int pthread_mutex_lock(pthread_mutex_t *mutex)
+int pthread_mutex_lock(pthread_mutex_t *mutex)
 {
   __CPROVER_HIDE:;
   #ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS
@@ -157,7 +158,7 @@ typedef signed char __CPROVER_mutex_t;
 #endif
 #endif
 
-inline int pthread_mutex_trylock(pthread_mutex_t *mutex)
+int pthread_mutex_trylock(pthread_mutex_t *mutex)
 {
   __CPROVER_HIDE:;
   int return_value;
@@ -208,7 +209,7 @@ typedef signed char __CPROVER_mutex_t;
 #endif
 #endif
 
-inline int pthread_mutex_unlock(pthread_mutex_t *mutex)
+int pthread_mutex_unlock(pthread_mutex_t *mutex)
 {
   __CPROVER_HIDE:;
 
@@ -256,7 +257,7 @@ typedef signed char __CPROVER_mutex_t;
 #endif
 #endif
 
-inline int pthread_mutex_destroy(pthread_mutex_t *mutex)
+int pthread_mutex_destroy(pthread_mutex_t *mutex)
 {
   __CPROVER_HIDE:;
 
@@ -290,14 +291,19 @@ inline int pthread_mutex_destroy(pthread_mutex_t *mutex)
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-extern __CPROVER_bool __CPROVER_threads_exited[];
-extern __CPROVER_thread_local unsigned long __CPROVER_thread_id;
+__CPROVER_bool __CPROVER_threads_exited[__CPROVER_constant_infinity_uint];
+__CPROVER_thread_local unsigned long __CPROVER_thread_id = 0;
+#if 0
+  // Destructor support is disabled as it is too expensive due to its extensive
+  // use of shared variables.
+__CPROVER_thread_local const void
+  *__CPROVER_thread_keys[__CPROVER_constant_infinity_uint];
+__CPROVER_thread_local void (
+  *__CPROVER_thread_key_dtors[__CPROVER_constant_infinity_uint])(void *);
+__CPROVER_thread_local unsigned long __CPROVER_next_thread_key = 0;
+#endif
 
-extern __CPROVER_thread_local const void *__CPROVER_thread_keys[];
-extern __CPROVER_thread_local void (*__CPROVER_thread_key_dtors[])(void *);
-extern __CPROVER_thread_local unsigned long __CPROVER_next_thread_key;
-
-inline void pthread_exit(void *value_ptr)
+void pthread_exit(void *value_ptr)
 {
   __CPROVER_HIDE:;
   if(value_ptr!=0) (void)*(char*)value_ptr;
@@ -314,6 +320,9 @@ inline void pthread_exit(void *value_ptr)
 #endif
   __CPROVER_threads_exited[__CPROVER_thread_id]=1;
   __CPROVER_assume(0);
+#ifdef LIBRARY_CHECK
+  __builtin_unreachable();
+#endif
 }
 
 /* FUNCTION: pthread_join */
@@ -328,11 +337,13 @@ inline void pthread_exit(void *value_ptr)
 #define __CPROVER_ERRNO_H_INCLUDED
 #endif
 
-extern __CPROVER_bool __CPROVER_threads_exited[];
-extern __CPROVER_thread_local unsigned long __CPROVER_thread_id;
-extern unsigned long __CPROVER_next_thread_id;
+__CPROVER_bool __CPROVER_threads_exited[__CPROVER_constant_infinity_uint];
+#ifndef LIBRARY_CHECK
+__CPROVER_thread_local unsigned long __CPROVER_thread_id = 0;
+#endif
+unsigned long __CPROVER_next_thread_id = 0;
 
-inline int pthread_join(pthread_t thread, void **value_ptr)
+int pthread_join(pthread_t thread, void **value_ptr)
 {
 __CPROVER_HIDE:;
 
@@ -365,11 +376,13 @@ __CPROVER_HIDE:;
 #endif
 
 #ifdef __APPLE__
-extern __CPROVER_bool __CPROVER_threads_exited[];
-extern __CPROVER_thread_local unsigned long __CPROVER_thread_id;
-extern unsigned long __CPROVER_next_thread_id;
+__CPROVER_bool __CPROVER_threads_exited[__CPROVER_constant_infinity_uint];
+#  ifndef LIBRARY_CHECK
+__CPROVER_thread_local unsigned long __CPROVER_thread_id = 0;
+unsigned long __CPROVER_next_thread_id = 0;
+#  endif
 
-inline int _pthread_join(pthread_t thread, void **value_ptr)
+int _pthread_join(pthread_t thread, void **value_ptr)
 {
 __CPROVER_HIDE:;
 
@@ -395,7 +408,7 @@ __CPROVER_HIDE:;
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-inline int pthread_rwlock_destroy(pthread_rwlock_t *lock)
+int pthread_rwlock_destroy(pthread_rwlock_t *lock)
 {
   __CPROVER_HIDE:;
   __CPROVER_assert(*((signed char *)lock)==0,
@@ -417,7 +430,7 @@ inline int pthread_rwlock_destroy(pthread_rwlock_t *lock)
 #endif
 
 #ifdef __CPROVER_CUSTOM_BITVECTOR_ANALYSIS
-inline void pthread_rwlock_cleanup(void *p)
+void pthread_rwlock_cleanup(void *p)
 {
   __CPROVER_HIDE:;
   __CPROVER_assert(__CPROVER_get_must(p, "rwlock_destroyed"),
@@ -425,7 +438,8 @@ inline void pthread_rwlock_cleanup(void *p)
 }
 #endif
 
-inline int pthread_rwlock_init(pthread_rwlock_t *lock,
+int pthread_rwlock_init(
+  pthread_rwlock_t *lock,
   const pthread_rwlockattr_t *attr)
 {
   __CPROVER_HIDE:;
@@ -446,7 +460,7 @@ inline int pthread_rwlock_init(pthread_rwlock_t *lock,
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-inline int pthread_rwlock_rdlock(pthread_rwlock_t *lock)
+int pthread_rwlock_rdlock(pthread_rwlock_t *lock)
 {
   __CPROVER_HIDE:;
   __CPROVER_atomic_begin();
@@ -465,7 +479,7 @@ inline int pthread_rwlock_rdlock(pthread_rwlock_t *lock)
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-inline int pthread_rwlock_tryrdlock(pthread_rwlock_t *lock)
+int pthread_rwlock_tryrdlock(pthread_rwlock_t *lock)
 {
   __CPROVER_HIDE:;
   __CPROVER_atomic_begin();
@@ -482,7 +496,7 @@ inline int pthread_rwlock_tryrdlock(pthread_rwlock_t *lock)
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-inline int pthread_rwlock_trywrlock(pthread_rwlock_t *lock)
+int pthread_rwlock_trywrlock(pthread_rwlock_t *lock)
 {
   __CPROVER_HIDE:;
   __CPROVER_atomic_begin();
@@ -499,7 +513,7 @@ inline int pthread_rwlock_trywrlock(pthread_rwlock_t *lock)
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-inline int pthread_rwlock_unlock(pthread_rwlock_t *lock)
+int pthread_rwlock_unlock(pthread_rwlock_t *lock)
 {
   __CPROVER_HIDE:;
   __CPROVER_assert(*((signed char *)lock)==1,
@@ -516,7 +530,7 @@ inline int pthread_rwlock_unlock(pthread_rwlock_t *lock)
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-inline int pthread_rwlock_wrlock(pthread_rwlock_t *lock)
+int pthread_rwlock_wrlock(pthread_rwlock_t *lock)
 {
   __CPROVER_HIDE:;
   __CPROVER_atomic_begin();
@@ -528,22 +542,23 @@ inline int pthread_rwlock_wrlock(pthread_rwlock_t *lock)
   return 0; // we never fail
 }
 
-/* FUNCTION: pthread_create */
+/* FUNCTION: __spawned_thread */
 
-#ifndef __CPROVER_PTHREAD_H_INCLUDED
-#include <pthread.h>
-#define __CPROVER_PTHREAD_H_INCLUDED
+__CPROVER_bool __CPROVER_threads_exited[__CPROVER_constant_infinity_uint];
+#ifndef LIBRARY_CHECK
+__CPROVER_thread_local unsigned long __CPROVER_thread_id = 0;
 #endif
+#if 0
+  // Destructor support is disabled as it is too expensive due to its extensive
+  // use of shared variables.
+__CPROVER_thread_local const void
+  *__CPROVER_thread_keys[__CPROVER_constant_infinity_uint];
+__CPROVER_thread_local void (
+  *__CPROVER_thread_key_dtors[__CPROVER_constant_infinity_uint])(void *);
+#endif
+__CPROVER_thread_local unsigned long __CPROVER_next_thread_key = 0;
 
-extern __CPROVER_bool __CPROVER_threads_exited[];
-extern __CPROVER_thread_local unsigned long __CPROVER_thread_id;
-extern unsigned long __CPROVER_next_thread_id;
-
-extern __CPROVER_thread_local const void *__CPROVER_thread_keys[];
-extern __CPROVER_thread_local void (*__CPROVER_thread_key_dtors[])(void *);
-extern __CPROVER_thread_local unsigned long __CPROVER_next_thread_key;
-
-inline void __spawned_thread(
+void __spawned_thread(
   unsigned long this_thread_id,
 #if 0
   // Destructor support is disabled as it is too expensive due to its extensive
@@ -592,11 +607,38 @@ __CPROVER_HIDE:;
   __CPROVER_threads_exited[this_thread_id] = 1;
 }
 
-inline int pthread_create(
-  pthread_t *thread, // must not be null
-  const pthread_attr_t *attr, // may be null
-  void * (*start_routine)(void *), // must not be null
-  void *arg) // may be null
+/* FUNCTION: pthread_create */
+
+#ifndef __CPROVER_PTHREAD_H_INCLUDED
+#  include <pthread.h>
+#  define __CPROVER_PTHREAD_H_INCLUDED
+#endif
+
+#ifndef LIBRARY_CHECK
+unsigned long __CPROVER_next_thread_id = 0;
+#  if 0
+__CPROVER_thread_local void (
+  *__CPROVER_thread_key_dtors[__CPROVER_constant_infinity_uint])(void *);
+#  endif
+__CPROVER_thread_local unsigned long __CPROVER_next_thread_key = 0;
+#endif
+
+void __spawned_thread(
+  unsigned long this_thread_id,
+#if 0
+  // Destructor support is disabled as it is too expensive due to its extensive
+  // use of shared variables.
+  void (**thread_key_dtors)(void *),
+#endif
+  unsigned long next_thread_key,
+  void *(*start_routine)(void *),
+  void *arg);
+
+int pthread_create(
+  pthread_t *thread,              // must not be null
+  const pthread_attr_t *attr,     // may be null
+  void *(*start_routine)(void *), // must not be null
+  void *arg)                      // may be null
 {
   __CPROVER_HIDE:;
   unsigned long this_thread_id;
@@ -642,9 +684,7 @@ inline int pthread_create(
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-inline int pthread_cond_init(
-    pthread_cond_t *cond,
-    const pthread_condattr_t *attr)
+int pthread_cond_init(pthread_cond_t *cond, const pthread_condattr_t *attr)
 { __CPROVER_HIDE:
   *((unsigned *)cond)=0;
   if(attr) (void)*attr;
@@ -658,8 +698,7 @@ inline int pthread_cond_init(
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-inline int pthread_cond_signal(
-  pthread_cond_t *cond)
+int pthread_cond_signal(pthread_cond_t *cond)
 { __CPROVER_HIDE:
   __CPROVER_atomic_begin();
   (*((unsigned *)cond))++;
@@ -674,8 +713,7 @@ inline int pthread_cond_signal(
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-inline int pthread_cond_broadcast(
-    pthread_cond_t *cond)
+int pthread_cond_broadcast(pthread_cond_t *cond)
 { __CPROVER_HIDE:
   __CPROVER_atomic_begin();
   *((unsigned *)cond)=(unsigned)-1;
@@ -690,9 +728,7 @@ inline int pthread_cond_broadcast(
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-inline int pthread_cond_wait(
-    pthread_cond_t *cond,
-    pthread_mutex_t *mutex)
+int pthread_cond_wait(pthread_cond_t *cond, pthread_mutex_t *mutex)
 { __CPROVER_HIDE:
 
   (void)*mutex;
@@ -803,14 +839,15 @@ int pthread_spin_trylock(pthread_spinlock_t *lock)
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-int __VERIFIER_nondet_int();
+int __VERIFIER_nondet_int(void);
 
 // no pthread_barrier_t on the Mac
 // slightly different declaration on OpenBSD
 #if !defined(__APPLE__) && !defined(__OpenBSD__)
-inline int pthread_barrier_init(
+int pthread_barrier_init(
   pthread_barrier_t *restrict barrier,
-  const pthread_barrierattr_t *restrict attr, unsigned count)
+  const pthread_barrierattr_t *restrict attr,
+  unsigned count)
 {
   __CPROVER_HIDE:;
   (void)barrier;
@@ -829,7 +866,7 @@ inline int pthread_barrier_init(
 
 // pthread_barrier_init has a slightly different decl on OpenBSD
 #if defined(__OpenBSD__)
-inline int pthread_barrier_init(
+int pthread_barrier_init(
   pthread_barrier_t *restrict barrier,
   pthread_barrierattr_t *restrict attr,
   unsigned count)
@@ -856,11 +893,11 @@ __CPROVER_HIDE:;
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-int __VERIFIER_nondet_int();
+int __VERIFIER_nondet_int(void);
 
 // no pthread_barrier_t on the Mac
 #ifndef __APPLE__
-inline int pthread_barrier_destroy(pthread_barrier_t *barrier)
+int pthread_barrier_destroy(pthread_barrier_t *barrier)
 {
   __CPROVER_HIDE:;
 
@@ -886,11 +923,11 @@ inline int pthread_barrier_destroy(pthread_barrier_t *barrier)
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-int __VERIFIER_nondet_int();
+int __VERIFIER_nondet_int(void);
 
 // no pthread_barrier_t on the Mac
 #ifndef __APPLE__
-inline int pthread_barrier_wait(pthread_barrier_t *barrier)
+int pthread_barrier_wait(pthread_barrier_t *barrier)
 {
   __CPROVER_HIDE:;
 
@@ -915,11 +952,17 @@ inline int pthread_barrier_wait(pthread_barrier_t *barrier)
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-extern __CPROVER_thread_local const void *__CPROVER_thread_keys[];
-extern __CPROVER_thread_local void (*__CPROVER_thread_key_dtors[])(void *);
-extern __CPROVER_thread_local unsigned long __CPROVER_next_thread_key;
+__CPROVER_thread_local const void
+  *__CPROVER_thread_keys[__CPROVER_constant_infinity_uint];
+#ifndef LIBRARY_CHECK
+#  if 0
+__CPROVER_thread_local void (
+  *__CPROVER_thread_key_dtors[__CPROVER_constant_infinity_uint])(void *);
+#  endif
+__CPROVER_thread_local unsigned long __CPROVER_next_thread_key = 0;
+#endif
 
-inline int pthread_key_create(pthread_key_t *key, void (*destructor)(void *))
+int pthread_key_create(pthread_key_t *key, void (*destructor)(void *))
 {
 __CPROVER_HIDE:;
   __CPROVER_thread_keys[__CPROVER_next_thread_key] = 0;
@@ -941,9 +984,10 @@ __CPROVER_HIDE:;
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-extern __CPROVER_thread_local const void *__CPROVER_thread_keys[];
+__CPROVER_thread_local const void
+  *__CPROVER_thread_keys[__CPROVER_constant_infinity_uint];
 
-inline int pthread_key_delete(pthread_key_t key)
+int pthread_key_delete(pthread_key_t key)
 {
 __CPROVER_HIDE:;
   __CPROVER_thread_keys[key] = 0;
@@ -957,9 +1001,10 @@ __CPROVER_HIDE:;
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-extern __CPROVER_thread_local const void *__CPROVER_thread_keys[];
+__CPROVER_thread_local const void
+  *__CPROVER_thread_keys[__CPROVER_constant_infinity_uint];
 
-inline void *pthread_getspecific(pthread_key_t key)
+void *pthread_getspecific(pthread_key_t key)
 {
 __CPROVER_HIDE:;
   return (void *)__CPROVER_thread_keys[key];
@@ -972,9 +1017,10 @@ __CPROVER_HIDE:;
 #define __CPROVER_PTHREAD_H_INCLUDED
 #endif
 
-extern __CPROVER_thread_local const void *__CPROVER_thread_keys[];
+__CPROVER_thread_local const void
+  *__CPROVER_thread_keys[__CPROVER_constant_infinity_uint];
 
-inline int pthread_setspecific(pthread_key_t key, const void *value)
+int pthread_setspecific(pthread_key_t key, const void *value)
 {
 __CPROVER_HIDE:;
   __CPROVER_thread_keys[key] = value;
