@@ -11,12 +11,10 @@ Author: Daniel Kroening, kroening@kroening.com
 
 #include "convert_integer_literal.h"
 
-#include <cassert>
 #include <cctype>
 
 #include <util/arith_tools.h>
 #include <util/config.h>
-#include <util/std_types.h>
 #include <util/std_expr.h>
 #include <util/string2int.h>
 
