@@ -11,8 +11,6 @@ Author: Daniel Kroening, kroening@kroening.com
 
 #include "convert_string_literal.h"
 
-#include <cassert>
-
 #include <util/arith_tools.h>
 #include <util/c_types.h>
 #include <util/unicode.h>
@@ -23,12 +21,12 @@ Author: Daniel Kroening, kroening@kroening.com
 std::basic_string<unsigned int> convert_one_string_literal(
   const std::string &src)
 {
-  assert(src.size()>=2);
+  PRECONDITION(src.size() >= 2);
 
   if(src[0]=='u' && src[1]=='8')
   {
-    assert(src[src.size()-1]=='"');
-    assert(src[2]=='"');
+    PRECONDITION(src[src.size() - 1] == '"');
+    PRECONDITION(src[2] == '"');
 
     std::basic_string<unsigned int> value=
       unescape_wide_string(std::string(src, 3, src.size()-4));
@@ -45,15 +43,15 @@ std::basic_string<unsigned int> convert_one_string_literal(
   }
   else if(src[0]=='L' || src[0]=='u' || src[0]=='U')
   {
-    assert(src[src.size()-1]=='"');
-    assert(src[1]=='"');
+    PRECONDITION(src[src.size() - 1] == '"');
+    PRECONDITION(src[1] == '"');
 
     return unescape_wide_string(std::string(src, 2, src.size()-3));
   }
   else
   {
-    assert(src[0]=='"');
-    assert(src[src.size()-1]=='"');
+    PRECONDITION(src[0] == '"');
+    PRECONDITION(src[src.size() - 1] == '"');
 
     std::string char_value=
       unescape_string(std::string(src, 1, src.size()-2));
@@ -93,17 +91,14 @@ exprt convert_string_literal(const std::string &src)
 
     // find start of sequence
     std::size_t j=src.find('"', i);
-    if(j==std::string::npos)
-      throw "invalid string constant '" + src + "'";
+    CHECK_RETURN(j != std::string::npos);
 
     // find end of sequence, considering escaping
     for(++j; j<src.size() && src[j]!='"'; ++j)
       if(src[j]=='\\') // skip next character
         ++j;
 
-    assert(j<=src.size());
-    if(j==src.size())
-      throw "non-terminated string constant '" + src + "'";
+    INVARIANT(j < src.size(), "non-terminated string constant '" + src + "'");
 
     std::string tmp_src=std::string(src, i, j-i+1);
     std::basic_string<unsigned int> tmp_value=
@@ -125,14 +120,14 @@ exprt convert_string_literal(const std::string &src)
     case 'L': subtype=wchar_t_type(); break;
     case 'u': subtype=char16_t_type(); break;
     case 'U': subtype=char32_t_type(); break;
-    default: assert(false);
+    default:
+      UNREACHABLE;
     }
 
     exprt result=exprt(ID_array);
     result.set(ID_C_string_constant, true);
-    result.type()=typet(ID_array);
-    result.type().subtype()=subtype;
-    result.type().set(ID_size, from_integer(value.size(), index_type()));
+    result.type() =
+      array_typet(subtype, from_integer(value.size(), c_index_type()));
 
     result.operands().resize(value.size());
     for(std::size_t i=0; i<value.size(); i++)
