@@ -6,8 +6,11 @@ Author: Daniel Kroening, kroening@kroening.com
 
 \*******************************************************************/
 
-#ifndef CPROVER_ANSI_C_CONVERT_STRING_LITERAL_H
-#define CPROVER_ANSI_C_CONVERT_STRING_LITERAL_H
+/// \file
+/// C/C++ Language Conversion
+
+#ifndef CPROVER_ANSI_C_LITERALS_CONVERT_STRING_LITERAL_H
+#define CPROVER_ANSI_C_LITERALS_CONVERT_STRING_LITERAL_H
 
 #include <string>
 
@@ -15,4 +18,4 @@ Author: Daniel Kroening, kroening@kroening.com
 
 exprt convert_string_literal(const std::string &src);
 
-#endif
+#endif // CPROVER_ANSI_C_LITERALS_CONVERT_STRING_LITERAL_H
