@@ -11,16 +11,13 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 
 #include "cpp_convert_type.h"
 
-#include <cassert>
-
-#include <util/arith_tools.h>
 #include <util/c_types.h>
 #include <util/config.h>
 #include <util/invariant.h>
+#include <util/message.h>
 #include <util/std_types.h>
 
 #include <ansi-c/ansi_c_convert_type.h>
-#include <ansi-c/gcc_types.h>
 
 #include "cpp_declaration.h"
 #include "cpp_name.h"
@@ -36,21 +33,16 @@ public:
   void write(typet &type) override;
 
   cpp_convert_typet(message_handlert &message_handler, const typet &type)
-    : ansi_c_convert_typet(message_handler)
+    : ansi_c_convert_typet(message_handler),
+      wchar_t_count(0),
+      char16_t_count(0),
+      char32_t_count(0)
   {
-    read(type);
+    source_location = type.source_location();
+    read_rec(type);
   }
 
 protected:
-  void clear() override
-  {
-    wchar_t_count = 0;
-    char16_t_count = 0;
-    char32_t_count = 0;
-
-    ansi_c_convert_typet::clear();
-  }
-
   void read_rec(const typet &type) override;
   void read_function_type(const typet &type);
   void read_template(const typet &type);
@@ -89,7 +81,8 @@ void cpp_convert_typet::read_rec(const typet &type)
   else if(type.id()==ID_array)
   {
     other.push_back(type);
-    cpp_convert_plain_type(other.back().subtype(), get_message_handler());
+    cpp_convert_plain_type(
+      to_array_type(other.back()).element_type(), message_handler);
   }
   else if(type.id()==ID_template)
   {
@@ -98,7 +91,8 @@ void cpp_convert_typet::read_rec(const typet &type)
   else if(type.id()==ID_frontend_pointer)
   {
     // add width and turn into ID_pointer
-    pointer_typet tmp(type.subtype(), config.ansi_c.pointer_width);
+    pointer_typet tmp(
+      to_type_with_subtype(type).subtype(), config.ansi_c.pointer_width);
     tmp.add_source_location()=type.source_location();
     if(type.get_bool(ID_C_reference))
       tmp.set(ID_C_reference, true);
@@ -127,13 +121,13 @@ void cpp_convert_typet::read_template(const typet &type)
   other.push_back(type);
   typet &t=other.back();
 
-  cpp_convert_plain_type(t.subtype(), get_message_handler());
+  cpp_convert_plain_type(to_type_with_subtype(t).subtype(), message_handler);
 
   irept &arguments=t.add(ID_arguments);
 
-  Forall_irep(it, arguments.get_sub())
+  for(auto &argument : arguments.get_sub())
   {
-    exprt &decl=static_cast<exprt &>(*it);
+    exprt &decl = static_cast<exprt &>(argument);
 
     // may be type or expression
     bool is_type=decl.get_bool(ID_is_type);
@@ -143,7 +137,7 @@ void cpp_convert_typet::read_template(const typet &type)
     }
     else
     {
-      cpp_convert_plain_type(decl.type(), get_message_handler());
+      cpp_convert_plain_type(decl.type(), message_handler);
     }
 
     // TODO: initializer
@@ -160,11 +154,11 @@ void cpp_convert_typet::read_function_type(const typet &type)
   // change subtype to return_type
   typet &return_type = t.return_type();
 
-  return_type.swap(t.subtype());
+  return_type.swap(to_type_with_subtype(t).subtype());
   t.remove_subtype();
 
   if(return_type.is_not_nil())
-    cpp_convert_plain_type(return_type, get_message_handler());
+    cpp_convert_plain_type(return_type, message_handler);
 
   // take care of parameter types
   code_typet::parameterst &parameters = t.parameters();
@@ -183,10 +177,11 @@ void cpp_convert_typet::read_function_type(const typet &type)
       cpp_declarationt &declaration=to_cpp_declaration(parameter_expr);
       source_locationt type_location=declaration.type().source_location();
 
-      cpp_convert_plain_type(declaration.type(), get_message_handler());
+      cpp_convert_plain_type(declaration.type(), message_handler);
 
-      // there should be only one declarator
-      assert(declaration.declarators().size()==1);
+      DATA_INVARIANT(
+        declaration.declarators().size() == 1,
+        "there should be only one declarator");
 
       cpp_declaratort &declarator=
         declaration.declarators().front();
@@ -206,7 +201,7 @@ void cpp_convert_typet::read_function_type(const typet &type)
         if(final_type.id()==ID_array)
         {
           // turn into pointer type
-          final_type=pointer_type(final_type.subtype());
+          final_type = pointer_type(to_array_type(final_type).element_type());
         }
 
         code_typet::parametert new_parameter(final_type);
@@ -218,7 +213,7 @@ void cpp_convert_typet::read_function_type(const typet &type)
         else if(cpp_name.is_simple_name())
         {
           irep_idt base_name=cpp_name.get_base_name();
-          assert(!base_name.empty());
+          CHECK_RETURN(!base_name.empty());
           new_parameter.set_identifier(base_name);
           new_parameter.set_base_name(base_name);
           new_parameter.add_source_location()=cpp_name.source_location();
@@ -253,8 +248,9 @@ void cpp_convert_typet::write(typet &type)
   {
     if(wchar_t_count || char16_t_count || char32_t_count)
     {
-      error().source_location = source_location;
-      error() << "illegal type modifier for defined type" << eom;
+      messaget log{message_handler};
+      log.error().source_location = source_location;
+      log.error() << "illegal type modifier for defined type" << messaget::eom;
       throw 0;
     }
 
@@ -333,15 +329,10 @@ void cpp_convert_plain_type(typet &type, message_handlert &message_handler)
     type.id() == ID_union || type.id() == ID_array || type.id() == ID_code ||
     type.id() == ID_unsignedbv || type.id() == ID_signedbv ||
     type.id() == ID_bool || type.id() == ID_floatbv || type.id() == ID_empty ||
-    type.id() == ID_constructor || type.id() == ID_destructor)
+    type.id() == ID_constructor || type.id() == ID_destructor ||
+    type.id() == ID_c_enum)
   {
   }
-  else if(type.id()==ID_c_enum)
-  {
-    // add width -- we use int, but the standard
-    // doesn't guarantee that
-    type.set(ID_width, config.ansi_c.int_width);
-  }
   else if(type.id() == ID_c_bool)
   {
     type.set(ID_width, config.ansi_c.bool_width);
@@ -360,7 +351,8 @@ void cpp_convert_auto(
 {
   if(dest.id() != ID_merged_type && dest.has_subtype())
   {
-    cpp_convert_auto(dest.subtype(), src, message_handler);
+    cpp_convert_auto(
+      to_type_with_subtype(dest).subtype(), src, message_handler);
     return;
   }
 
