@@ -12,10 +12,11 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 #ifndef CPROVER_CPP_CPP_CONVERT_TYPE_H
 #define CPROVER_CPP_CPP_CONVERT_TYPE_H
 
-#include <util/type.h>
+class message_handlert;
+class typet;
 
-void cpp_convert_plain_type(typet &);
+void cpp_convert_plain_type(typet &, message_handlert &);
 
-void cpp_convert_auto(typet &dest, const typet &src);
+void cpp_convert_auto(typet &dest, const typet &src, message_handlert &);
 
 #endif // CPROVER_CPP_CPP_CONVERT_TYPE_H
