@@ -14,7 +14,6 @@ Author: Daniel Kroening, kroening@cs.cmu.edu
 #include <ansi-c/merged_type.h>
 
 #include <ostream>
-#include <cassert>
 
 void cpp_declaratort::output(std::ostream &out) const
 {
@@ -51,8 +50,8 @@ typet cpp_declaratort::merge_type(const typet &declaration_type) const
     }
     else
     {
-      assert(!t.id().empty());
-      p=&t.subtype();
+      DATA_INVARIANT(!t.id().empty(), "empty type");
+      p = &t.add_subtype();
     }
   }
 
